==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/SCREENFLOWUSERGROUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SCREENFLOWUSERGROUPID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SCREENFLOWUSERGROUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENFLOWSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENFLOWUSERGROUPID_Type", propOrder = {
    "screenflowsequence",
    "usergroupid"
})
public class SCREENFLOWUSERGROUPID_Type {

    @XmlElement(name = "SCREENFLOWSEQUENCE")
    protected long screenflowsequence;
    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;

    /**
     * Obtient la valeur de la propriété screenflowsequence.
     * 
     */
    public long getSCREENFLOWSEQUENCE() {
        return screenflowsequence;
    }

    /**
     * Définit la valeur de la propriété screenflowsequence.
     * 
     */
    public void setSCREENFLOWSEQUENCE(long value) {
        this.screenflowsequence = value;
    }

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/SCREENFLOWUSERGROUPID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SCREENFLOWUSERGROUPID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SCREENFLOWUSERGROUPID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENFLOWSEQUENCE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SCREENFLOWUSERGROUPID_Type", propOrder = {
    "screenflowsequence",
    "usergroupid"
})
public class SCREENFLOWUSERGROUPID_Type {

    @XmlElement(name = "SCREENFLOWSEQUENCE")
    protected long screenflowsequence;
    @XmlElement(name = "USERGROUPID", required = true)
    protected USERGROUPID_Type usergroupid;

    /**
     * Gets the value of the screenflowsequence property.
     * 
     */
    public long getSCREENFLOWSEQUENCE() {
        return screenflowsequence;
    }

    /**
     * Sets the value of the screenflowsequence property.
     * 
     */
    public void setSCREENFLOWSEQUENCE(long value) {
        this.screenflowsequence = value;
    }

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

}
